@@ -507,18 +507,32 @@ impl VGER {
         }
     }
 
-    /// Renders text.
-    pub fn text(&mut self, text: &str, size: u32, color: Color, max_width: Option<f32>) {
+    fn setup_layout(&mut self, text: &str, size: u32, max_width: Option<f32>) {
+
+        let scale = self.device_px_ratio;
+
         self.layout.reset(&LayoutSettings {
-            max_width,
+            max_width: max_width.map(|w| w*scale),
             ..LayoutSettings::default()
         });
 
+        let scaled_size = size as f32 * scale; 
+
         self.layout.append(
             &[&self.glyph_cache.font],
-            &TextStyle::new(text, size as f32, 0),
+            &TextStyle::new(text, scaled_size, 0),
         );
 
+    }
+
+    /// Renders text.
+    pub fn text(&mut self, text: &str, size: u32, color: Color, max_width: Option<f32>) {
+
+        self.setup_layout(text, size, max_width);
+
+        let scale = self.device_px_ratio;
+        let scaled_size = size as f32 * scale;
+
         let paint = self.color_paint(color);
         let xform = self.add_xform() as u32;
 
@@ -529,17 +543,17 @@ impl VGER {
             // println!("glyph {:?}", c);
             let info = self
                 .glyph_cache
-                .get_glyph(c, size * self.device_px_ratio as u32);
+                .get_glyph(c, scaled_size);
 
             if let Some(rect) = info.rect {
                 let mut prim = Prim::default();
                 prim.prim_type = PrimType::Glyph as u32;
                 prim.xform = xform;
                 prim.quad_bounds = [
-                    glyph.x,
-                    glyph.y,
-                    glyph.x + glyph.width as f32,
-                    glyph.y + glyph.height as f32,
+                    glyph.x / scale,
+                    glyph.y / scale,
+                    (glyph.x + glyph.width as f32) / scale,
+                    (glyph.y + glyph.height as f32) / scale,
                 ];
                 // println!("quad_bounds: {:?}", prim.quad_bounds);
                 prim.tex_bounds = [
@@ -564,22 +578,17 @@ impl VGER {
 
     /// Calculates the bounds for text.
     pub fn text_bounds(&mut self, text: &str, size: u32, max_width: Option<f32>) -> LocalRect {
-        self.layout.reset(&LayoutSettings {
-            max_width,
-            ..LayoutSettings::default()
-        });
 
-        self.layout.append(
-            &[&self.glyph_cache.font],
-            &TextStyle::new(text, size as f32, 0),
-        );
+        self.setup_layout(text, size, max_width);
 
         let mut min = LocalPoint::new(f32::MAX, f32::MAX);
         let mut max = LocalPoint::new(f32::MIN, f32::MIN);
 
+        let scale = self.device_px_ratio;
+
         for glyph in self.layout.glyphs() {
-            min = min.min([glyph.x, glyph.y].into());
-            max = max.max([glyph.x + glyph.width as f32, glyph.y + glyph.height as f32].into());
+            min = min.min([glyph.x / scale, glyph.y / scale].into());
+            max = max.max([(glyph.x + glyph.width as f32) / scale, (glyph.y + glyph.height as f32) / scale ].into());
         }
 
         LocalRect::new(min, (max - min).into())
@@ -595,21 +604,15 @@ impl VGER {
         let mut rects = vec![];
         rects.reserve(text.len());
 
-        self.layout.reset(&LayoutSettings {
-            max_width,
-            ..LayoutSettings::default()
-        });
+        self.setup_layout(text, size, max_width);
 
-        self.layout.append(
-            &[&self.glyph_cache.font],
-            &TextStyle::new(text, size as f32, 0),
-        );
+        let s = 1.0/self.device_px_ratio;
 
         for glyph in self.layout.glyphs() {
             rects.push(LocalRect::new(
                 [glyph.x, glyph.y].into(),
                 [glyph.width as f32, glyph.height as f32].into(),
-            ))
+            ).scale(s, s))
         }
 
         rects
@@ -621,15 +624,9 @@ impl VGER {
         size: u32,
         max_width: Option<f32>,
     ) -> Vec<LineMetrics> {
-        self.layout.reset(&LayoutSettings {
-            max_width,
-            ..LayoutSettings::default()
-        });
 
-        self.layout.append(
-            &[&self.glyph_cache.font],
-            &TextStyle::new(text, size as f32, 0),
-        );
+        self.setup_layout(text, size, max_width);
+        let s = 1.0/self.device_px_ratio;
 
         let mut rects = vec![];
         rects.reserve(text.len());
@@ -650,7 +647,7 @@ impl VGER {
                 rects.push(LineMetrics {
                     glyph_start: line.glyph_start,
                     glyph_end: line.glyph_end,
-                    bounds: rect,
+                    bounds: rect.scale(s, s),
                 });
             }
         }
