@@ -214,6 +214,9 @@ fn test_color_hex() {
     assert_eq!(c.g, 0.831373);
     assert_eq!(c.b, 1.0);
     assert_eq!(c.a, 1.0);
+
+    let c = Color::hex_const("#009BBA");
+    assert_eq!(c.r, 0.0);
 }
 
 #[test]
@@ -452,6 +455,20 @@ fn text() {
     render_test(&mut vger, &device, &queue, "text.png", true);
 }
 
+#[test]
+fn text_scale() {
+    let (device, queue) = block_on(setup());
+
+    let mut vger = VGER::new(&device, wgpu::TextureFormat::Rgba8UnormSrgb);
+
+    vger.begin(512.0, 512.0, 2.0);
+
+    vger.translate([32.0, 256.0]);
+    vger.text("This is a test", 32, Color::CYAN, None);
+
+    render_test(&mut vger, &device, &queue, "text_scale.png", true);
+}
+
 #[test]
 fn text_box() {
     let (device, queue) = block_on(setup());
